@@ -26,6 +26,7 @@ from esi.models import Token
 from .app_settings import (
     OPCALENDAR_EVE_UNI_URL,
     OPCALENDAR_SPECTRE_URL,
+    OPCALENDAR_FUNINC_URL,
 )
 
 DEFAULT_TASK_PRIORITY = 6
@@ -69,7 +70,7 @@ def import_fleets():
 	
 	for feed in feeds:
 		if feed.source=="Spectre Fleet":
-			logger.debug("Spectre Fleet import feed active. Pulling events from %s" % OPCALENDAR_SPECTRE_URL)
+			logger.debug("Spectre: import feed active. Pulling events from %s" % OPCALENDAR_SPECTRE_URL)
 			#Get fleets from SF RSS
 			d = feedparser.parse(OPCALENDAR_SPECTRE_URL)
 			for entry in d.entries:
@@ -78,7 +79,7 @@ def import_fleets():
 					#Only active fleets
 					if not "[RESERVED]" in entry.title:
 
-						logger.debug("Import even found: %s" % entry.title)
+						logger.debug("Spectre: Import even found: %s" % entry.title)
 						
 						date_object = datetime.strptime(entry.published,'%a, %d %b %Y %H:%M:%S %z')
 						date_object.strftime('%Y-%m-%dT%H:%M')
@@ -88,7 +89,7 @@ def import_fleets():
 
 						#If we get the event from API it should not be removed
 						if original is not None:
-							logger.debug("Event: %s already in database" % entry.title)
+							logger.debug("Spectre: Event: %s already in database" % entry.title)
 							event_ids_to_remove.remove(original.id)
 
 						else:
@@ -96,25 +97,25 @@ def import_fleets():
 								operation_type=feed.operation_type,
 								title=entry.title,
 								host=feed.host,
-								doctrine="",
-								formup_system="",
+								doctrine="see details",
+								formup_system="see details",
 								description=entry.description,
 								start_time=date_object, 
 								end_time=date_object, 
-								fc="",
+								fc="see details",
 								visibility="import",
 								user_id = feed.creator.id,
 								eve_character_id = feed.eve_character.id
 							)
 							
-							logger.debug("Saved new event in database: %s" % entry.title)
+							logger.debug("Spectre: Saved new event in database: %s" % entry.title)
 							
 							event.save()
 
 		if feed.source=="EVE University":
-			logger.debug("EVE University import feed active. Pulling events from %s" % OPCALENDAR_EVE_UNI_URL)
+			logger.debug("EVE Uni: import feed active. Pulling events from %s" % OPCALENDAR_EVE_UNI_URL)
 			#Get fleets from EVE UNI Ical
-			url = OPCALENDAR_EVE_UNI_URL
+			url = OPCALENDAR_FUNINC_URL
 			c = Calendar(requests.get(url).text)
 			for entry in c.events:
 				#Filter only class events as they are the only public events in eveuni
@@ -125,14 +126,14 @@ def import_fleets():
 					end_date = datetime.utcfromtimestamp(entry.end.timestamp).replace(tzinfo=pytz.utc)
 					title = re.sub("[\(\[].*?[\)\]]", "", entry.name)
 
-					logger.debug("Import even found: %s" % title)
+					logger.debug("EVE Uni: Import even found: %s" % title)
 
 					# Check if we already have the event stored
 					original = Event.objects.filter(start_time=start_date, title=title).first()
 
 					#If we get the event from API it should not be removed	
 					if original is not None:
-						logger.debug("Event: %s already in database" % title)
+						logger.debug("EVE Uni: Event: %s already in database" % title)
 						event_ids_to_remove.remove(original.id)
 
 					else:		
@@ -140,19 +141,60 @@ def import_fleets():
 							operation_type=feed.operation_type,
 							title=title,
 							host=feed.host,
-							doctrine="",
-							formup_system="",
+							doctrine="see details",
+							formup_system="see details",
 							description=entry.description,
 							start_time=start_date, 
 							end_time=end_date, 
-							fc="",
+							fc="see details",
 							visibility="import",
 							user_id = feed.creator.id,
 							eve_character_id = feed.eve_character.id
 						)
 
-						logger.debug("Saved new event in database: %s" % title)
+						logger.debug("EVE Uni: Saved new EVE UNI event in database: %s" % title)
 						event.save()
+
+		if feed.source=="Fun Inc.":
+			logger.debug("FUN INC: import feed active. Pulling events from %s" % OPCALENDAR_EVE_UNI_URL)
+			#Get fleets from EVE UNI Ical
+			url = OPCALENDAR_EVE_UNI_URL
+			c = Calendar(requests.get(url).text)
+			for entry in c.events:
+
+				start_date = datetime.utcfromtimestamp(entry.begin.timestamp).replace(tzinfo=pytz.utc)
+				end_date = datetime.utcfromtimestamp(entry.end.timestamp).replace(tzinfo=pytz.utc)
+				title = re.sub("[\(\[].*?[\)\]]", "", entry.name)
+
+				logger.debug("FUN INC: Import even found: %s" % title)
+
+				# Check if we already have the event stored
+				original = Event.objects.filter(start_time=start_date, title=title).first()
+
+				#If we get the event from API it should not be removed	
+				if original is not None:
+					logger.debug("FUN INC: Event: %s already in database" % title)
+					event_ids_to_remove.remove(original.id)
+
+				else:		
+					event = Event(
+						operation_type=feed.operation_type,
+						title=title,
+						host=feed.host,
+						doctrine="see details",
+						formup_system="see details",
+						description=entry.description,
+						start_time=start_date, 
+						end_time=end_date, 
+						fc="see details",
+						visibility="import",
+						user_id = feed.creator.id,
+						eve_character_id = feed.eve_character.id
+					)
+
+					logger.debug("FUN INC: Saved new FUN INC. event in database: %s" % title)
+					event.save()
+
 	logger.debug("Removing all events that we did not get over API")
 	# Remove all events we did not see from API					
 	Event.objects.filter(pk__in=event_ids_to_remove).delete()
